SZMethod enum

Supported HTTP request methods used by SZ Core.

These methods are used when making API requests through the networking utilities provided by the package.

Example:

await SZCore.request(
  method: SZMethod.post,
  url: '/login',
  body: {
    'email': email,
    'password': password,
  },
);
Inheritance
Available extensions

Values

get → const SZMethod

Retrieves data from the server.

post → const SZMethod

Sends new data to the server.

delete → const SZMethod

Removes existing data from the server.

put → const SZMethod

Updates existing data by replacing it completely.

patch → const SZMethod

Updates existing data partially.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SZMethod>
A constant List of the values in this enum, in order of their declaration.