MethodChannelSzCore class

An implementation of SzCorePlatform that uses method channels.

Inheritance

Constructors

MethodChannelSzCore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDefaultHeader() Future<Map<String, String>>
override
getDeviceInfo() Future<DeviceInfo>
override
getScreenSize() Future<({double height, double width})>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showToast(String message, Color bg, Color color, double size, double duration) Future<String?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited